mediapack -- python materials repository
========================================

.. image:: https://travis-ci.org/cpplanes/mediapack.svg?branch=master
  :target: https://travis-ci.org/cpplanes/mediapack

.. image:: https://coveralls.io/repos/github/cpplanes/mediapack/badge.svg?branch=master
  :target: https://coveralls.io/github/cpplanes/mediapack?branch=master
